@@ -4,6 +4,7 @@ class PDF::Font::Loader::FreeType {
     use PDF::IO::Util :pack;
     use PDF::Writer;
     use NativeCall;
+    use PDF::Font::Loader::Enc::Identity;
     use PDF::Font::Loader::Enc::Identity-H;
     use PDF::Font::Loader::Enc::Type1;
     use Font::FreeType;
@@ -15,14 +16,15 @@ class PDF::Font::Loader::FreeType {
     constant Px = 64.0;
 
     has Font::FreeType::Face $.face is required;
-    has $!encoder handles <decode>;
-    has Blob $.font-stream is required;
+    use PDF::Font::Loader::Enc;
+    has PDF::Font::Loader::Enc $!encoder handles <decode>;
+    has $.font-stream is required;
     use PDF::Content::Font;
     has PDF::Content::Font $!dict;
-    has UInt $!first-char;
-    has UInt $!last-char;
-    has uint16 @!widths;
-    my subset EncodingScheme of Str where 'mac'|'win'|'identity-h';
+    has UInt $.first-char;
+    has UInt $.last-char;
+    has uint16 @.widths;
+    my subset EncodingScheme where 'mac'|'win'|'zapf'|'sym'|'identity'|'identity-h'|PDF::Font::Loader::Enc;
     has EncodingScheme $!enc;
     has Bool $.embed = True;
 
@@ -33,9 +35,12 @@ class PDF::Font::Loader::FreeType {
             if self!font-format eq 'Type1' && $!enc eq 'identity-h';
         die "can't use identity-h encoding with unembedded fonts"
             if ! $!embed && $!enc eq 'identity-h';
-        $!encoder = $!enc eq 'identity-h'
-            ?? PDF::Font::Loader::Enc::Identity-H.new: :$!face
-            !! PDF::Font::Loader::Enc::Type1.new: :$!enc, :$!face;
+        $!encoder = do given $!enc {
+            when PDF::Font::Loader::Enc { $_ }
+            when 'identity' { PDF::Font::Loader::Enc::Identity.new: :$!face }
+            when 'identity-h' { PDF::Font::Loader::Enc::Identity-H.new: :$!face }
+            default { PDF::Font::Loader::Enc::Type1.new: :$!enc, :$!face; }
+        }
         $!encoder.differences = @differences
             if @differences;
     }
@@ -322,24 +327,22 @@ class PDF::Font::Loader::FreeType {
     }
 
     method kern(Str $text) {
-        my FT_Pos $x = 0;
-        my FT_Pos $y = 0;
-        my FT_UInt $prev-idx = 0;
-        my $has-kerning = $!face.has-kerning;
-        my $kerning = FT_Vector.new;
-        my $face-struct = $!face.struct;
-        my $glyph-slot = $face-struct.glyph;
-        my $str = '';
+        my FT_UInt      $prev-idx = 0;
+        my Bool         $has-kerning = $!face.has-kerning;
+        my FT_Vector    $kerning .= new;
+        my FT_Face      $face-struct = $!face.struct;
+        my FT_GlyphSlot $glyph-slot = $face-struct.glyph;
+        my Str          $str = '';
+        my Numeric      $stringwidth = 0.0;
         my @chunks;
-        my Numeric $stringwidth = 0.0;
         my $scale = 1000 / $!face.units-per-EM;
 
         for $text.ords -> $char-code {
-            my FT_UInt $this-idx =  $face-struct.FT_Get_Char_Index( $char-code );
-            if $has-kerning && $this-idx {
+            my FT_UInt $this-idx = $face-struct.FT_Get_Char_Index( $char-code );
+            if $this-idx {
                 ft-try({ $face-struct.FT_Load_Glyph( $this-idx, FT_LOAD_NO_SCALE); });
                 $stringwidth += $glyph-slot.metrics.hori-advance * $scale;
-                if $prev-idx {
+                if $has-kerning && $prev-idx {
                     ft-try({ $face-struct.FT_Get_Kerning($prev-idx, $this-idx, FT_KERNING_UNSCALED, $kerning); });
                     my $dx = ($kerning.x * $scale).round;
                     if $dx {
@@ -349,9 +352,9 @@ class PDF::Font::Loader::FreeType {
                         $str = '';
                     }
                 }
+                $str ~= $char-code.chr;
+                $prev-idx = $this-idx;
             }
-            $str ~= $char-code.chr;
-            $prev-idx = $this-idx;
         }
 
         @chunks.push: $str
